@@ -45,4 +45,15 @@
         tmp<-as.numeric(t(tmp[1,])%*%inverse%*%tmp[1,])
         return(sqrt(tmp))
     }
-}
\ No newline at end of file
+}
+
+# time weighted dynamic time warping
+.mtwdtw <- function(x, time_vector=0, stepness = -0.5, midpoint = 35, cycle_length="year", time_scale="day") {
+    # message(midpoint)
+    twdtw::twdtw(
+        x=data.frame(time=time_vector, v=x[[1]]), 
+        y=data.frame(time=time_vector, v=x[[2]]),
+        time_weight = c(stepness=stepness,midpoint=midpoint),
+        cycle_length = cycle_length, 
+        time_scale = time_scale)
+}
